//[mahjong-utils](../../../../index.md)/[mahjongutils.yaku](../../index.md)/[Yakus](../index.md)/[Default](index.md)

# Default

[common]\
object [Default](index.md) : [Yakus](../index.md)

## Properties

| Name | Summary |
|---|---|
| [allCommonYaku](../all-common-yaku.md) | [common]<br>val [allCommonYaku](../all-common-yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../../-yaku/index.md)&gt;<br>所有通常役种 |
| [allExtraYaku](../all-extra-yaku.md) | [common]<br>val [allExtraYaku](../all-extra-yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../../-yaku/index.md)&gt;<br>所有额外役种（与手牌无关的役种） |
| [allExtraYakuman](../all-extra-yakuman.md) | [common]<br>val [allExtraYakuman](../all-extra-yakuman.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../../-yaku/index.md)&gt;<br>所有额外役满（与手牌无关的役种） |
| [allYaku](../all-yaku.md) | [common]<br>val [allYaku](../all-yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../../-yaku/index.md)&gt;<br>所有役种 |
| [allYakuman](../all-yakuman.md) | [common]<br>val [allYakuman](../all-yakuman.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../../-yaku/index.md)&gt;<br>所有役满役种 |
| [Chankan](../-chankan.md) | [common]<br>val [Chankan](../-chankan.md): [Yaku](../../-yaku/index.md)<br>枪杠 |
| [Chanta](../-chanta.md) | [common]<br>val [Chanta](../-chanta.md): [Yaku](../../-yaku/index.md)<br>混全带幺九 |
| [Chihou](../-chihou.md) | [common]<br>val [Chihou](../-chihou.md): [Yaku](../../-yaku/index.md)<br>地和 |
| [Chinitsu](../-chinitsu.md) | [common]<br>val [Chinitsu](../-chinitsu.md): [Yaku](../../-yaku/index.md)<br>清一色 |
| [Chinroto](../-chinroto.md) | [common]<br>val [Chinroto](../-chinroto.md): [Yaku](../../-yaku/index.md)<br>清老头 |
| [Chitoi](../-chitoi.md) | [common]<br>val [Chitoi](../-chitoi.md): [Yaku](../../-yaku/index.md)<br>七对子 |
| [Chun](../-chun.md) | [common]<br>val [Chun](../-chun.md): [Yaku](../../-yaku/index.md)<br>中 |
| [Churen](../-churen.md) | [common]<br>val [Churen](../-churen.md): [Yaku](../../-yaku/index.md)<br>九莲宝灯 |
| [ChurenNineWaiting](../-churen-nine-waiting.md) | [common]<br>val [ChurenNineWaiting](../-churen-nine-waiting.md): [Yaku](../../-yaku/index.md)<br>纯正九莲宝灯（九莲宝灯九面） |
| [Daisangen](../-daisangen.md) | [common]<br>val [Daisangen](../-daisangen.md): [Yaku](../../-yaku/index.md)<br>大三元 |
| [Daisushi](../-daisushi.md) | [common]<br>val [Daisushi](../-daisushi.md): [Yaku](../../-yaku/index.md)<br>大四喜 |
| [Haitei](../-haitei.md) | [common]<br>val [Haitei](../-haitei.md): [Yaku](../../-yaku/index.md)<br>海底捞月 |
| [Haku](../-haku.md) | [common]<br>val [Haku](../-haku.md): [Yaku](../../-yaku/index.md)<br>白 |
| [Hatsu](../-hatsu.md) | [common]<br>val [Hatsu](../-hatsu.md): [Yaku](../../-yaku/index.md)<br>发 |
| [Honitsu](../-honitsu.md) | [common]<br>val [Honitsu](../-honitsu.md): [Yaku](../../-yaku/index.md)<br>混一色 |
| [Honroto](../-honroto.md) | [common]<br>val [Honroto](../-honroto.md): [Yaku](../../-yaku/index.md)<br>混老头 |
| [Houtei](../-houtei.md) | [common]<br>val [Houtei](../-houtei.md): [Yaku](../../-yaku/index.md)<br>河底捞鱼 |
| [Ipe](../-ipe.md) | [common]<br>val [Ipe](../-ipe.md): [Yaku](../../-yaku/index.md)<br>一杯口 |
| [Ippatsu](../-ippatsu.md) | [common]<br>val [Ippatsu](../-ippatsu.md): [Yaku](../../-yaku/index.md)<br>一发 |
| [Ittsu](../-ittsu.md) | [common]<br>val [Ittsu](../-ittsu.md): [Yaku](../../-yaku/index.md)<br>一气通贯 |
| [Junchan](../-junchan.md) | [common]<br>val [Junchan](../-junchan.md): [Yaku](../../-yaku/index.md)<br>纯全带幺九 |
| [Kokushi](../-kokushi.md) | [common]<br>val [Kokushi](../-kokushi.md): [Yaku](../../-yaku/index.md)<br>国士无双 |
| [KokushiThirteenWaiting](../-kokushi-thirteen-waiting.md) | [common]<br>val [KokushiThirteenWaiting](../-kokushi-thirteen-waiting.md): [Yaku](../../-yaku/index.md)<br>国士无双十三面 |
| [Lyuiso](../-lyuiso.md) | [common]<br>val [Lyuiso](../-lyuiso.md): [Yaku](../../-yaku/index.md)<br>绿一色 |
| [options](../options.md) | [common]<br>val [options](../options.md): [HoraOptions](../../../mahjongutils.hora/-hora-options/index.md) |
| [Pinhu](../-pinhu.md) | [common]<br>val [Pinhu](../-pinhu.md): [Yaku](../../-yaku/index.md)<br>平和 |
| [Richi](../-richi.md) | [common]<br>val [Richi](../-richi.md): [Yaku](../../-yaku/index.md)<br>立直 |
| [Rinshan](../-rinshan.md) | [common]<br>val [Rinshan](../-rinshan.md): [Yaku](../../-yaku/index.md)<br>岭上自摸 |
| [RoundWind](../-round-wind.md) | [common]<br>val [RoundWind](../-round-wind.md): [Yaku](../../-yaku/index.md)<br>场风 |
| [Ryanpe](../-ryanpe.md) | [common]<br>val [Ryanpe](../-ryanpe.md): [Yaku](../../-yaku/index.md)<br>两杯口 |
| [Sananko](../-sananko.md) | [common]<br>val [Sananko](../-sananko.md): [Yaku](../../-yaku/index.md)<br>三暗刻 |
| [Sandoko](../-sandoko.md) | [common]<br>val [Sandoko](../-sandoko.md): [Yaku](../../-yaku/index.md)<br>三色同刻 |
| [Sankantsu](../-sankantsu.md) | [common]<br>val [Sankantsu](../-sankantsu.md): [Yaku](../../-yaku/index.md)<br>三杠子 |
| [Sanshoku](../-sanshoku.md) | [common]<br>val [Sanshoku](../-sanshoku.md): [Yaku](../../-yaku/index.md)<br>三色同顺 |
| [SelfWind](../-self-wind.md) | [common]<br>val [SelfWind](../-self-wind.md): [Yaku](../../-yaku/index.md)<br>自风 |
| [Shosangen](../-shosangen.md) | [common]<br>val [Shosangen](../-shosangen.md): [Yaku](../../-yaku/index.md)<br>小三元 |
| [Shousushi](../-shousushi.md) | [common]<br>val [Shousushi](../-shousushi.md): [Yaku](../../-yaku/index.md)<br>小四喜 |
| [Suanko](../-suanko.md) | [common]<br>val [Suanko](../-suanko.md): [Yaku](../../-yaku/index.md)<br>四暗刻 |
| [SuankoTanki](../-suanko-tanki.md) | [common]<br>val [SuankoTanki](../-suanko-tanki.md): [Yaku](../../-yaku/index.md)<br>四暗刻单骑 |
| [Sukantsu](../-sukantsu.md) | [common]<br>val [Sukantsu](../-sukantsu.md): [Yaku](../../-yaku/index.md)<br>四杠子 |
| [Tanyao](../-tanyao.md) | [common]<br>val [Tanyao](../-tanyao.md): [Yaku](../../-yaku/index.md)<br>断幺 |
| [Tenhou](../-tenhou.md) | [common]<br>val [Tenhou](../-tenhou.md): [Yaku](../../-yaku/index.md)<br>天和 |
| [Toitoi](../-toitoi.md) | [common]<br>val [Toitoi](../-toitoi.md): [Yaku](../../-yaku/index.md)<br>对对和 |
| [Tsuiso](../-tsuiso.md) | [common]<br>val [Tsuiso](../-tsuiso.md): [Yaku](../../-yaku/index.md)<br>字一色 |
| [Tsumo](../-tsumo.md) | [common]<br>val [Tsumo](../-tsumo.md): [Yaku](../../-yaku/index.md)<br>自摸 |
| [WRichi](../-w-richi.md) | [common]<br>val [WRichi](../-w-richi.md): [Yaku](../../-yaku/index.md)<br>两立直 |

## Functions

| Name | Summary |
|---|---|
| [getYaku](../get-yaku.md) | [common]<br>fun [getYaku](../get-yaku.md)(name: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Yaku](../../-yaku/index.md)<br>根据役种名获取役种 |
